@@ -259,6 +259,8 @@ SMBSlave::SMBError SMBSlave::errnumToKioError(const SMBUrl &url, const int errNu
         return SMBError{ ERR_INTERNAL, i18n("Bad file descriptor") };
     case ETIMEDOUT:
         return SMBError{ ERR_SERVER_TIMEOUT, url.host() };
+    case ENOTEMPTY:
+        return SMBError{ ERR_CANNOT_RMDIR, url.toDisplayString() };
 #ifdef ENOTUNIQ
     case ENOTUNIQ:
         return SMBError{ ERR_SLAVE_DEFINED, i18n("The given name could not be resolved to a unique server. "
@@ -314,7 +316,7 @@ void SMBSlave::listDir( const QUrl& kurl )
    m_current_url = kurl;
 
    int                 dirfd;
-   struct smbc_dirent  *dirp = NULL;
+   struct smbc_dirent  *dirp = nullptr;
    UDSEntry    udsentry;
    bool dir_is_root = true;
 
@@ -331,7 +333,7 @@ void SMBSlave::listDir( const QUrl& kurl )
        do {
            qCDebug(KIO_SMB) << "smbc_readdir ";
            dirp = smbc_readdir(dirfd);
-           if(dirp == 0)
+           if(dirp == nullptr)
                break;
 
            // Set name
